import typer
import time

# Auth app
auth_app = typer.Typer()

@auth_app.command('status')
def auth_status():
    '''
    Check login status

    Check the current login system.
    '''
    print('Print whether logged in or not')

@auth_app.command('login')
def login(
    token: str = typer.Option(..., help='Authenticate the app through token')
):
    '''
    Login with an application token.

    Get the auth token from our website
    '''
    print('Logging using the authorization token: {token}')

@auth_app.command('logout')
def logout():
    '''
    Logout from your session

    Get the auth token from our website
    '''
    print(f'Logging out of current session')

@auth_app.callback()
def callback():
    '''
    Authorization (logging in/out)

    Login and get authorization token etc.

    You can login/logout check authorization token with this.
    '''

if __name__ == '__main__':
    auth_app()



import typer

scenario_app = typer.Typer()



# Scenario app
@scenario_app.command('list')
def scenario_list():
    scenarios = ['smoke-and-fire', 'ppe-detection', 'edge-dev2']
    print(f'Scenarios : {scenarios}')

@scenario_app.command('add')
def scenario_add(scenario: str):
    print(f'Adding scenario : {scenario}')

@scenario_app.command('remove')
def scenario_remove(scenario: str):
    print(f'Removing scenario : {scenario}')



if __name__ == '__main__':
    scenario_app()



import os
import platform
import sys
from pathlib import Path
import typer
from rich import print
from rich.progress import track
import time

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # edgectl root directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH
ROOT = Path(os.path.relpath(ROOT, Path.cwd()))  # relative

from edgectl.auth import auth_app
from edgectl.device import device_app
from edgectl.scenario import scenario_app
from edgectl.camera import camera_app

app = typer.Typer()
app.add_typer(auth_app, name='auth')
app.add_typer(device_app, name='device')
app.add_typer(scenario_app, name='scenario')
app.add_typer(camera_app, name='camera')

@app.callback()
def app_callback():
    '''
    edgectl utility

    This utility can be used to manage cameras and scenarios.

    You can add and remove cameras. or you can add and remove scenarios
    with this application. This application can also be used to restart
    the edge device or the containers running there. Try out and let us
    know if you run into any issues.
    '''


if __name__ == "__main__":
    app()


import typer

device_app = typer.Typer()

# Device app
@device_app.command('list')
def device_list():
    '''
    List available devices

    Get a list of all available [processing] devices
    '''
    devices = ['oos-training', 'edge-dev1', 'edge-dev2']
    print(f'Devices : {devices}')

@device_app.command('select')
def device_select(device: str):
    '''
    Select a device

    Not sure why is this needed at this time.
    '''
    print(f'Selecting device : {device}')

@device_app.command('modules')
def device_modules():
    '''
    List running modules on the device

    Again this does not make much sense at this time. Let's revisit.
    '''
    modules = ['edgeCtl', 'edgeEvents']
    print(f'Listing modules : {modules}')

@device_app.command('stats')
def device_gpu_mem_stats():
    '''
    Machine health (GPU/Mem stats)

    Show machine health (GPU/memory stats). This can be used to
    determine if more scenarios can be run on the machine or not.
    '''
    print('Getting gpu/mem stats')

if __name__ == '__main__':
    device_app()



import typer
import time
from rich.progress import track

camera_app = typer.Typer()


# Camera app
@camera_app.command('list')
def camera_list():
    cameras = ['OFFICE-01', 'OFFICE-02']
    print(f'Cameras : {cameras}')

@camera_app.command('add')
def camera_add(camera: str):
    print(f'Adding camera : {camera}')

@camera_app.command('remove')
def camera_remove(camera: str):
    print(f'Removing camera : {camera}')

@camera_app.command('install')
def camera_install(
    name:str = typer.Option(..., help='camera name to install'),
    uri: str = typer.Option(..., help='camera uri (rtsp/hls/http)')
    ):
    total = 0
    for value in track(range(100), description="Adding camera..."):
        # Fake processing time
        time.sleep(0.01)
        total += 1
    print(f"Processed {total} things.")

@camera_app.callback()
def callback():
    '''
    Manage adding/removing cameras

    Users can add a camera through its name and uri

    A new camera will be created in the system.
    '''

if __name__ == '__main__':
    camera_app()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['edgectl']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.28.2,<3.0.0', 'typer[all]>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['edgectl = edgectl.main:app']}

setup_kwargs = {
    'name': 'edgectl',
    'version': '0.1.2',
    'description': '',
    'long_description': '# edgectl\n\nControl edge devices through this utility\n\n',
    'author': 'Harsh Murari',
    'author_email': 'hmurari@visionify.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
